# -*- coding: utf-8 -*-
"""
###############################################
AgileUFRJ - Implementando as teses do PPGI
###############################################

:Author: *Carlo E. T. Oliveira*
:Contact: carlo@nce.ufrj.br
:Date: $Date: 2009/09/02  $
:Status: This is a "work in progress"
:Revision: $Revision: 0.01 $
:Home: `LABASE <http://labase.nce.ufrj.br/>`__
:Copyright: ©2009, `GPL <http://is.gd/3Udt>__. 
"""

from main import WsgiApp
from webtest import TestApp
from webob import Request, Response

#import mocker
#from mocker import Mocker

import model
import unittest

import hashlib

REGISTRY_FORM = { "user":"teste",
                  "passwd": "teste",
                  "npasswd": "teste",
                  "name": "fulano",
                  "lastname": "de tal",
                  "email": "teste@teste.com",
                  "mkey": "6yt276Yt197AgR5667dGkLO3" }

LOGIN_FORM = { "user":"teste", "passwd": "teste" }

registry = {}
login = {}

#class TestCadastro(mocker.MockerTestCase):
class TestCadastro(unittest.TestCase):
  """Testes unitários para o cadastro"""

  def setUp(self):
    #self.mock = Mocker()
    #MEMBER = self.mock.mock()
    model.MEMBER = {}
    self.app = TestApp(WsgiApp())
    registry.update(REGISTRY_FORM)
    login.update(LOGIN_FORM)

  def tearDown(self):
    #self.mock.restore()
    #self.mock.verify()
    #self.mock,MEMBER =None,None
    pass

  def test_returns_home_on_root(self):
    "Return the home page on '/'"
    response = self.app.get('/')
    self.assert_(u'Bem-vindo ao Oi Tonomundo' in response, "Erro: Não exibiu tela de Home!")

  def test_open_a_login_screen(self):
    "a form containing login, senha"
    response = self.app.get('/login')
    assert 'input id="user" prompt="login" name="user" value="login" autocomplete="off"' in response, "Erro: Não exibiu tela de login!"
  
  def test_returns_registry_form_on_root(self):
    "a form containing registry data"
    response = self.app.get('/registry')
    assert 'input name="user" id="user" value="" type="text"' in response, "Erro: Não exibiu formulário de cadastro!"

  def test_accept_registry_ok(self):
    "test_accept_registry_ok"
    response = self.app.post('/registry', registry)
    assert u'302 Found' in response.status, "Erro: Não redirecionou!"
    assert u'/' in response.headers["Location"], "Erro: Redirecionou para o lugar errado!"

  def test_reject_registry_double_user(self):
    "test_reject_registry_double_user"
    self.app.post('/registry', registry)
    response = self.app.post('/registry', registry)
    assert u'Login já existe!' in response, "Erro: Não exibiu a mensagem 'Login já existe!'"

  def test_reject_registry_without_magickey(self):
    "test_reject_registry_without_magickey"
    registry["mkey"]="teste"
    response = self.app.post('/registry', registry)
    assert u'Chave mágica incorreta!' in response, "Erro: Não exibiu a mensagem 'Chave mágica incorreta!'"

  def test_reject_registry_without_pass_confirm(self):
    "test_reject_registry_without_pass_confirm"
    registry["npasswd"]="npasswd"
    response = self.app.post('/registry', registry)
    assert u'Senha diferente da confirmação!' in response, "Erro: Não exibiu a mensagem 'Senha diferente da confirmação!'"

  def test_reject_registry_without_required_form(self):
    "test_reject_registry_without_required_form"
    registry["name"]=""
    registry["lastname"]=""
    response = self.app.post('/registry', registry)
    assert u'campos obrigatórios não preenchidos!' in response, "Erro: Não exibiu a mensagem 'campos obrigatórios não preenchidos!'"

  def test_login_unsuccessful(self):
    "Return the form containing login, senha with message"
    response = self.app.post('/login', login)
    assert u'Senha incorreta ou usuário inexistente.' in response, "Erro: Não exibiu tela de Login com mensagem de erro!"

  def test_login_successful(self):
    "Return the home page on '/user'"
    self.app.post('/registry', registry)
    response = self.app.post('/login', login)
    assert u'302 Found' in response.status, "Erro: Não redirecionou para página do usuário!"
    assert u'/' + login["user"] in response.headers["Location"], "Erro: Redirecionou para o lugar errado!"

  def test_user_home(self):
    "Return the home page on '/user'"
    self.app.post('/registry', registry)
    self.app.post('/login', login)
    response = self.app.get('/' + login["user"])
    assert u'Pré-inscrição no VI Encontro Nacional TONOMUNDO' in response, "Erro: Não exibiu a página do usuário!"
